#!/bin/bash
# Copyright (c) 1997-2003 by ilink Kommunikationssysteme GmbH.  All Rights Reserved.
#
# These script will call the JavaInstaller based on Console for CANortelMeridian
#
# Calling user must have root permissions!
#

PATH=$PATH:/usr/bin:/usr/sbin:/sbin


# Check directory
if [ ! -d "./java-vm" -o ! -f "linux-installer.sh" ] ;then
        echo ""
        echo "You are not in the right directory"
        echo "Please change to Installer directory (CANortel-installer)"
        echo "Installer cancelled"
        echo ""
        exit 1
fi

# Check for root permissions
perm=`id -u`
if [ "$perm" != "0" ]; then
    echo ""
    echo "You must be root to start the Installer"
    echo "Installer cancelled"
    echo ""
    exit 1
fi

# Check for required library (libstdc++-libc6.1-1.so.2)
libcheck=`ldconfig -p | grep libstdc++-libc6.1-1.so.2`
if [ ! "$libcheck" ]; then
   echo ""
   echo "The library libstdc++-libc6.1-1.so.2 was not found on your system."
   echo "This library is required for CANortelMeridian, Please install..."
   echo "Installer cancelled"
   echo ""
   exit 1
fi

# untar jre for CANortelMeridian Installer
echo ""
echo "Unpack jre for CANortelMeridian Installer..."
tar -xzf ./java-vm/linux/jre.tgz -C ./java-vm/linux/
echo ""


# default Variables CA

LANG="deu"
SERVER_PORT="25535"
SYMPOSIUM_HOSTNAME="localhost"
SYMPOSIUM_PORT="3000"
OP_PREFIX=""
INSTALLPATH="/usr/local/ilink/CANortelMeridian"
INSTALLCONFIG="install.config" 					 # name install config file
INSTALLERFILE="ca_nortel_meridian_install*.jar"  # name java install pkg
INSTALLLOGFILE="CANortelMeridian-install.log"    # name install log file

# variables install script

JAVAHOME="./java-vm/linux/jre"
DEBUGOPTION="-DTRACE=true -DSTACKTRACE=true"
checkParameter="0"


# get and confirm all Parameters

while [ "$checkParameter" != "OK" ]
do 
	clear
	echo "Installer for Console"

	echo -e "Symposium Hostname ["$SYMPOSIUM_HOSTNAME"]:\c " 
	read SYMPOSIUM_HOSTNAME_TMP

	if [ "$SYMPOSIUM_HOSTNAME_TMP" != "" ];then
   	   SYMPOSIUM_HOSTNAME="$SYMPOSIUM_HOSTNAME_TMP"
	fi

	echo -e "Symposium Port ["$SYMPOSIUM_PORT"]:\c " 
	read SYMPOSIUM_PORT_TMP

	if [ "$SYMPOSIUM_PORT_TMP" != "" ];then
   	   SYMPOSIUM_PORT="$SYMPOSIUM_PORT_TMP"
	fi

	echo -e "Server Port ["$SERVER_PORT"]:\c " 
	read SERVER_PORT_TMP

	if [ "$SERVER_PORT_TMP" != "" ];then
   	   SERVER_PORT="$SERVER_PORT_TMP"
	fi

	echo -e "Out-Side Line Prefix ["$OP_PREFIX"]:\c " 
	read OP_PREFIX_TMP

	if [ "$OP_PREFIX_TMP" != "" ];then
   	   OP_PREFIX="$OP_PREFIX_TMP"
	fi

	echo -e "Installation Path ["$INSTALLPATH"]:\c " 
	read INSTALLPATH_TMP

	if [ "$INSTALLPATH_TMP" != "" ];then
   	   INSTALLPATH="$INSTALLPATH_TMP"
	fi

	echo "--------------------------------------------"
	echo "          Check your settings!"
	echo ""
	echo " Symposium Hostname:       $SYMPOSIUM_HOSTNAME"
	echo " Symposium Port:           $SYMPOSIUM_PORT"
	echo " Server Port:              $SERVER_PORT"
	echo " Out-Side Line Prefix:     $OP_PREFIX"
	echo " Installation Path:        $INSTALLPATH"
	echo ""
	echo "---------------------------------------------"

	checker="0"	
	echo -e "All settings right? Then type OK: \c" 
	read checker

	if [ "$checker" == "OK" ];then
   	   checkParameter="OK"
	fi

done

# create a config file for installation
cat > $INSTALLCONFIG << EOF
<AutomatedInstallation langpack="$LANG">
    <HelloPanel/>
    <UserInputPanel>
        <userInput>
            <entry key="SERVER_PORT" value="$SERVER_PORT"/>
            <entry key="SYMPOSIUM_HOSTNAME" value="$SYMPOSIUM_HOSTNAME"/>
            <entry key="OP_PREFIX" value="$OP_PREFIX"/>
            <entry key="SYMPOSIUM_PORT" value="$SYMPOSIUM_PORT"/>
        </userInput>
    </UserInputPanel>
    <TargetPanel>
        <installpath>$INSTALLPATH</installpath>
    </TargetPanel>
    <PacksPanel>
        <pack name="CANortel" index="0" selected="true"/>
    </PacksPanel>
    <InstallPanel/>
    <FinishPanel/>
</AutomatedInstallation>
EOF

# start the IzPack Installer
$JAVAHOME/bin/java $DEBUGOPTION -jar $INSTALLERFILE $INSTALLCONFIG | tee $INSTALLLOGFILE | egrep '\(./.\)'

# Clean logfile from rubbish
mv $INSTALLLOGFILE logfile_tmp
cat logfile_tmp | grep -v "current OS" > $INSTALLLOGFILE
rm logfile_tmp


#remove created install.config file
rm $INSTALLCONFIG
